@@ -5,7 +5,7 @@
 ##############################################################
 
 # Author: Christos Zamantzas <christos.zamantzas@gmail.com>
-# Version: 0.4.4-10
+# Version: 0.4.4-12
 
 import os
 import sys
@@ -188,7 +188,9 @@ class MyForm(QtGui.QMainWindow):
                    self.ui.comboBoxGPSSend.setCurrentIndex(0) 
                 elif GPSSEND == 'email':
                    self.ui.comboBoxGPSSend.setCurrentIndex(1)
-                  
+                elif GPSSEND == 'both':
+                   self.ui.comboBoxGPSSend.setCurrentIndex(2)
+                   
                 self.ui.lineEmailUsername.setText("%s" % USER)
                 self.ui.lineEmailPassword.setText("%s" % PASSWORD)
                 self.ui.lineEmailAddress.setText("%s" % EMAILADDRESS)
